isOkAnd method

bool isOkAnd(
  1. bool f(
    1. T
    )
)

isOkAnd returns true if Results represents an ok result and the additional code of f returns true.

Implementation

bool isOkAnd(bool Function(T) f) => isOk() ? f(_value as T) : false;